package org.bluej.cleanprojectextension;

import bluej.extensions.BPackage;
import bluej.extensions.ExtensionException;
import java.awt.event.ActionEvent;
import java.io.File;
import java.io.IOException;
import javax.swing.AbstractAction;

/**
 * An abstract action to delete all the .class and .ctxt files, 
 * and the doc directory, from a BlueJ project
 * 
 * @author Ian Utting
 * @version 1.0
 */

public final class DeleteFilesAction extends AbstractAction {
    private final BPackage currentPackage;
        
    public DeleteFilesAction(String menuName, BPackage bp) {
        putValue(AbstractAction.NAME, menuName);
        currentPackage = bp;
    }
        
    @Override
    public void actionPerformed(ActionEvent anEvent) {  
        // Run the clean-up itself on a separate thread
        (new Thread() {
            @Override
            public void run() {
                try {
                    BPackage[] bpl = currentPackage.getProject().getPackages();
                    for(BPackage bp : bpl) {
                        clean(bp.getDir());
                    }
                } catch (IOException ioe) { 
                } catch(ExtensionException ee) { }
            }
        }).start();
    }
        
    /**
     * Remove the .class and .ctxt files, and (recursively) the doc directory from dir
     * @param dir   the folder to be cleaned
     * @throws IOException 
     */
    private void clean(File dir) throws IOException {
        
        // Shouldn't happen
        if(!dir.isDirectory()) return;

        for (File c : dir.listFiles()) {
            // Delete all .class and .ctxt files
            if (c.getName().endsWith(".class")) c.delete();
            if (c.getName().endsWith(".ctxt")) c.delete();
            
            // and (recursively) the doc folder
            if (c.isDirectory() && c.getName().equals("doc")) {
                totallyRemove(c);
            }
        }
    }

    /**
     * Recursively remove a directory
     * @param f the directory to be removed
     * @throws IOException 
     */
    private void totallyRemove(File f) throws IOException {
        if (f.isDirectory()) {
            for (File c : f.listFiles())
                totallyRemove(c);
        }
        f.delete();
    }
}
